@@ -1,8 +1,8 @@
-from django.views.generic import ListView, DetailView, CreateView
-from django.core.urlresolvers import reverse
 from django.contrib import messages
+from django.core.urlresolvers import reverse
 from django.http import HttpResponseRedirect
 from django.utils.translation import ugettext_lazy as _
+from django.views.generic import ListView, DetailView, CreateView
 
 from forms import TicketCreateForm, TicketCommentCreateForm
 from models import Ticket
@@ -15,6 +15,7 @@ class MyTicketListView(ListView):
     def get_queryset(self):
         return Ticket.objects.filter(creator=self.request.user)
 
+
 class MyTicketDetailView(DetailView):
     model = Ticket
     template_name = 'tickets/ticket_mydetail.html'
@@ -37,11 +38,12 @@ class MyTicketDetailView(DetailView):
         comment.author = self.request.user
         comment.ticket = Ticket.objects.get(id=self.kwargs['pk'])
         comment.save()
-        messages.success(self.request, _("Your comment has been successfully added to the ticket."))
+        messages.success(self.request, _(u"Your comment has been successfully added to the ticket."))
 
     def get_queryset(self):
         return Ticket.objects.filter(creator=self.request.user)
 
+
 class TicketCreateView(CreateView):
     form_class = TicketCreateForm
     template_name = 'tickets/ticket_create.html'
@@ -51,5 +53,5 @@ class TicketCreateView(CreateView):
         ticket.creator = self.request.user
         ticket.save()
         self.success_url = reverse('tickets:detail', args=[ticket.id])
-        messages.success(self.request, _("Your ticket has been successfully created."))
+        messages.success(self.request, _(u"Your ticket has been successfully created."))
         return super(TicketCreateView, self).form_valid(form)
